==> cscec5b-wzxt-impl-3.0.0-20201102.093453-8-sources.jar: com/ejianc/business/wzxt/controller/WeighDetailController.java <==
package com.ejianc.business.wzxt.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.wzxt.bean.PlanDetailEntity;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import java.util.List;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.wzxt.bean.WeighDetailEntity;
import com.ejianc.business.wzxt.service.IWeighDetailService;
import com.ejianc.business.wzxt.vo.WeighDetailVO;

/**
 * 智能称重实体明细表
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("weighDetail")
public class WeighDetailController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private IWeighDetailService weighDetailService;
    @Autowired
    private IOrgApi orgApi;
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<WeighDetailVO> saveOrUpdate(@RequestBody WeighDetailVO saveorUpdateVO) {
    	WeighDetailEntity entity = BeanMapper.map(saveorUpdateVO, WeighDetailEntity.class);
        weighDetailService.saveOrUpdate(entity, false);
    	WeighDetailVO vo = BeanMapper.map(entity, WeighDetailVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/MaterialBatch", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<WeighDetailVO>> MaterialBatch(@RequestBody List<WeighDetailVO> saveorUpdateBatchVO) {
        Long orgId = InvocationInfoProxy.getOrgId();
        CommonResponse<OrgVO> orgVo = orgApi.getOneById(orgId);
        if(!orgVo.isSuccess()) {
            return CommonResponse.success("查询组织详情失败！");
        }
        OrgVO orgVoData = orgVo.getData();
        //项目部,查询组织物料设置,以组织物料设置为默认值进行保存
        if (orgVoData.getOrgType() == 5){
            //查询项目目上级组织物料设置
            Long parentId = orgVoData.getParentId();
            LambdaQueryWrapper<WeighDetailEntity> queryWrapperDetail = Wrappers.<WeighDetailEntity>lambdaQuery();
            queryWrapperDetail.eq(WeighDetailEntity::getOrgId, parentId);
            List<WeighDetailEntity> weighDetailEntityList = weighDetailService.list(queryWrapperDetail);
            if(weighDetailEntityList != null && weighDetailEntityList.size() > 0) {
                for (WeighDetailVO weighDetailVO : saveorUpdateBatchVO){
                    for (WeighDetailEntity weighDetailEntity : weighDetailEntityList){
                        if (weighDetailVO.getMaterialId().equals(weighDetailEntity.getMaterialId())){
                            weighDetailVO.setWeighFlag(weighDetailEntity.getWeighFlag());
                            weighDetailVO.setTransformRate(weighDetailEntity.getTransformRate());
                        }
                    }
                }
            }
        }
        for (WeighDetailVO weighDetailVO : saveorUpdateBatchVO){
            weighDetailVO.setOrgId(orgId);
        }
        List<WeighDetailEntity> listEntity = BeanMapper.mapList(saveorUpdateBatchVO, WeighDetailEntity.class);
        weighDetailService.saveOrUpdateBatch(listEntity);
    	List<WeighDetailVO> vo = BeanMapper.mapList(listEntity, WeighDetailVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<WeighDetailVO> queryDetail(Long id) {
    	WeighDetailEntity entity = weighDetailService.selectById(id);
    	WeighDetailVO vo = BeanMapper.map(entity, WeighDetailVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<WeighDetailVO> vos) {
        weighDetailService.removeByIds(vos.stream().map(WeighDetailVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<WeighDetailVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        //模糊搜索：材料名称、材料编码
        //高级搜索：智能称重
        fuzzyFields.add("materialCode");
        fuzzyFields.add("materialName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));

        IPage<WeighDetailEntity> page = weighDetailService.queryPage(param,false);
        IPage<WeighDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), WeighDetailVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}

==> cscec5b-wzxt-impl-3.0.0-20201104.023409-17-sources.jar: com/ejianc/business/wzxt/controller/WeighDetailController.java <==
package com.ejianc.business.wzxt.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.wzxt.bean.PlanDetailEntity;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.kit.collection.ListUtil;
import org.apache.commons.collections.ListUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.wzxt.bean.WeighDetailEntity;
import com.ejianc.business.wzxt.service.IWeighDetailService;
import com.ejianc.business.wzxt.vo.WeighDetailVO;

/**
 * 智能称重实体明细表
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("weighDetail")
public class WeighDetailController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private IWeighDetailService weighDetailService;
    @Autowired
    private IOrgApi orgApi;
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<WeighDetailVO> saveOrUpdate(@RequestBody WeighDetailVO saveorUpdateVO) {
    	WeighDetailEntity entity = BeanMapper.map(saveorUpdateVO, WeighDetailEntity.class);
        weighDetailService.saveOrUpdate(entity, false);
    	WeighDetailVO vo = BeanMapper.map(entity, WeighDetailVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    /**
     * @Description saveOrUpdate
     */
    @RequestMapping(value = "/MaterialBatch", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<WeighDetailVO>> MaterialBatch(@RequestBody List<WeighDetailVO> saveorUpdateBatchVO) {

        Long orgId = InvocationInfoProxy.getOrgId();
        LambdaQueryWrapper<WeighDetailEntity> queryWrapperDetailOld = Wrappers.<WeighDetailEntity>lambdaQuery();
        queryWrapperDetailOld.eq(WeighDetailEntity::getOrgId, orgId);
        List<WeighDetailEntity> weighDetailEntityListOld = weighDetailService.list(queryWrapperDetailOld);
        List<WeighDetailVO> removeList =  new ArrayList<>();
        if (ListUtil.isNotEmpty(weighDetailEntityListOld)) {

            //过滤重复的物料
            for (WeighDetailVO weighDetailVO : saveorUpdateBatchVO){
                for (WeighDetailEntity weighDetailEntity : weighDetailEntityListOld){
                    if (weighDetailVO.getMaterialId().equals(weighDetailEntity.getMaterialId())){
                        removeList.add(weighDetailVO);
                    }

                }
            }
        }
        if (ListUtil.isNotEmpty(removeList)){
            saveorUpdateBatchVO.removeAll(removeList);
        }
        CommonResponse<OrgVO> orgVo = orgApi.getOneById(orgId);
        if(!orgVo.isSuccess()) {
            return CommonResponse.success("查询组织详情失败！");
        }
        OrgVO orgVoData = orgVo.getData();
        //项目部,查询组织物料设置,以组织物料设置为默认值进行保存
        if (orgVoData.getOrgType() == 5){
            //查询项目目上级组织物料设置
            Long parentId = orgVoData.getParentId();
            LambdaQueryWrapper<WeighDetailEntity> queryWrapperDetail = Wrappers.<WeighDetailEntity>lambdaQuery();
            queryWrapperDetail.eq(WeighDetailEntity::getOrgId, parentId);
            List<WeighDetailEntity> weighDetailEntityList = weighDetailService.list(queryWrapperDetail);
            if(weighDetailEntityList != null && weighDetailEntityList.size() > 0) {
                for (WeighDetailVO weighDetailVO : saveorUpdateBatchVO){
                    for (WeighDetailEntity weighDetailEntity : weighDetailEntityList){
                        if (weighDetailVO.getMaterialId().equals(weighDetailEntity.getMaterialId())){
                            weighDetailVO.setWeighFlag(weighDetailEntity.getWeighFlag());
                            weighDetailVO.setTransformRate(weighDetailEntity.getTransformRate());
                        }
                    }
                }
            }
        }
        for (WeighDetailVO weighDetailVO : saveorUpdateBatchVO){
            weighDetailVO.setOrgId(orgId);
        }
        List<WeighDetailEntity> listEntity = BeanMapper.mapList(saveorUpdateBatchVO, WeighDetailEntity.class);
        weighDetailService.saveOrUpdateBatch(listEntity);
    	List<WeighDetailVO> vo = BeanMapper.mapList(listEntity, WeighDetailVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<WeighDetailVO> queryDetail(Long id) {
    	WeighDetailEntity entity = weighDetailService.selectById(id);
    	WeighDetailVO vo = BeanMapper.map(entity, WeighDetailVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<WeighDetailVO> vos) {
        weighDetailService.removeByIds(vos.stream().map(WeighDetailVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<WeighDetailVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        //模糊搜索：材料名称、材料编码
        //高级搜索：智能称重
        fuzzyFields.add("materialCode");
        fuzzyFields.add("materialName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));

        IPage<WeighDetailEntity> page = weighDetailService.queryPage(param,false);
        IPage<WeighDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), WeighDetailVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}
